@@ -15,7 +15,7 @@ import sys
 from oslo_serialization import jsonutils
 from oslo_utils import reflection
 
-from heatclient.openstack.common._i18n import _
+from heatclient._i18n import _
 
 verbose = 0
 
@@ -77,8 +77,7 @@ class HTTPMultipleChoices(HTTPException):
     code = 300
 
     def __str__(self):
-        self.details = _("Requested version of Heat API is not"
-                         "available.")
+        self.details = _("Requested version of Heat API is not available.")
         return (_("%(name)s (HTTP %(code)s) %(details)s") %
                 {
                 'name': reflection.get_class_name(self, fully_qualified=False),
@@ -122,6 +121,10 @@ class HTTPNotFound(NotFound):
     pass
 
 
+class NoUniqueMatch(HTTPException):
+    pass
+
+
 class HTTPMethodNotAllowed(HTTPException):
     code = 405
 
