@@ -18,8 +18,7 @@ import sys
 
 from oslo_serialization import jsonutils
 from oslo_utils import strutils
-import six
-from six.moves.urllib import request
+from urllib import request
 import yaml
 
 from heatclient._i18n import _
@@ -114,7 +113,7 @@ def do_stack_create(hc, args):
 
     fields = {
         'stack_name': args.name,
-        'disable_rollback': not(args.enable_rollback),
+        'disable_rollback': not args.enable_rollback,
         'parameters': utils.format_all_parameters(args.parameters,
                                                   args.parameter_file,
                                                   args.template_file,
@@ -185,6 +184,10 @@ def do_stack_adopt(hc, args):
 
     adopt_url = utils.normalise_file_path_to_url(args.adopt_file)
     adopt_data = request.urlopen(adopt_url).read()
+    yaml_adopt_data = yaml.safe_load(adopt_data) or {}
+
+    files = yaml_adopt_data.get('files', {})
+    files.update(env_files)
 
     if not len(adopt_data):
         raise exc.CommandError('Invalid adopt-file, no data!')
@@ -198,10 +201,10 @@ def do_stack_adopt(hc, args):
 
     fields = {
         'stack_name': args.name,
-        'disable_rollback': not(args.enable_rollback),
+        'disable_rollback': not args.enable_rollback,
         'adopt_stack_data': adopt_data,
         'parameters': utils.format_parameters(args.parameters),
-        'files': dict(list(env_files.items())),
+        'files': files,
         'environment': env
     }
 
@@ -259,7 +262,7 @@ def do_stack_preview(hc, args):
 
     fields = {
         'stack_name': args.name,
-        'disable_rollback': not(args.enable_rollback),
+        'disable_rollback': not args.enable_rollback,
         'timeout_mins': args.timeout,
         'parameters': utils.format_all_parameters(args.parameters,
                                                   args.parameter_file,
@@ -302,7 +305,7 @@ def do_stack_delete(hc, args):
 
     try:
         if not args.yes and sys.stdin.isatty():
-            prompt_response = six.moves.input(
+            prompt_response = input(
                 _("Are you sure you want to delete this stack(s) [y/N]? ")
             ).lower()
             if not prompt_response.startswith('y'):
@@ -538,9 +541,9 @@ def do_stack_update(hc, args):
         try:
             rollback = strutils.bool_from_string(args.rollback, strict=True)
         except ValueError as ex:
-            raise exc.CommandError(six.text_type(ex))
+            raise exc.CommandError(str(ex))
         else:
-            fields['disable_rollback'] = not(rollback)
+            fields['disable_rollback'] = not rollback
     # TODO(pshchelo): remove the following 'else' clause after deprecation
     # period of --enable-rollback switch and assign -r shortcut to --rollback
     else:
@@ -560,7 +563,7 @@ def do_stack_update(hc, args):
         fields = ['state', 'resource_name', 'resource_type',
                   'resource_identity']
 
-        for k in resource_changes.get("resource_changes", {}).keys():
+        for k in resource_changes.get("resource_changes", {}):
             for i in range(len(resource_changes["resource_changes"][k])):
                 resource_changes["resource_changes"][k][i]['state'] = k
 
@@ -724,7 +727,7 @@ def do_output_list(hc, args):
     utils.print_list(outputs['outputs'], fields, formatters=formatters)
 
 
-@utils.arg('id', metavar='<NAME or ID>',
+@utils.arg('id', metavar='<NAME or ID>',  # noqa: C901
            help=_('Name or ID of stack to query.'))
 @utils.arg('output', metavar='<OUTPUT NAME>', nargs='?', default=None,
            help=_('Name of an output to display.'))
@@ -736,7 +739,7 @@ def do_output_list(hc, args):
 @utils.arg('--with-detail', default=False, action="store_true",
            help=_('Enable detail information presented, like '
                   'key and description.'))
-def do_output_show(hc, args):
+def do_output_show(hc, args):  # noqa: C901
     """Show a specific stack output."""
     show_deprecated('heat output-show', 'openstack stack output show')
 
@@ -1063,7 +1066,7 @@ def do_resource_signal(hc, args):
         data_url = utils.normalise_file_path_to_url(data_file)
         data = request.urlopen(data_url).read()
     if data:
-        if isinstance(data, six.binary_type):
+        if isinstance(data, bytes):
             data = data.decode('utf-8')
         try:
             data = jsonutils.loads(data)
@@ -1337,9 +1340,7 @@ def do_config_create(hc, args):
     }
     hc.stacks.validate(template=validate_template)
 
-    config['name'] = args.name
-
-    sc = hc.software_configs.create(**config)
+    sc = hc.software_configs.create(name=args.name, **config)
     print(jsonutils.dumps(sc.to_dict(), indent=2))
 
 
